/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#include "abstractdatalogger.h"

#include <QDateTime>
#include <math.h>
#include <QtDebug>

AbstractDataLogger::AbstractDataLogger(QObject *parent) :
    QObject(parent)
{
    currentTs = 0;
    temperatureTotal = 0.0;
    humidityTotal = 0.0;
    dewPointTotal = 0.0;
    samples = 0;
}

bool AbstractDataLogger::connectLogger() {
    currentTs = nextTs();
    qDebug() << "Start TS:" << QDateTime::fromMSecsSinceEpoch(currentTs);
    temperatureTotal = 0.0;
    humidityTotal = 0.0;
    dewPointTotal = 0.0;
    samples = 0;

    return true;
}

qint64 AbstractDataLogger::nextTs() {
    return ceil(QDateTime::currentDateTime().toMSecsSinceEpoch() / 300000.0) * 300000;
}

void AbstractDataLogger::logData(float temperature, float humidity, float dewPoint) {

    auto ts = nextTs();

    if (ts > currentTs) {
        // Time to average it.
        float averageTemperature = temperatureTotal / samples;
        float averageHumidity = humidityTotal / samples;
        float averageDewPoint = dewPointTotal / samples;

        // Then store it
        insertSample(currentTs, averageTemperature, averageHumidity,
                     averageDewPoint);

        // Then reset everything for the next time period.
        temperatureTotal = temperature;
        humidityTotal = humidity;
        dewPointTotal = dewPoint;
        samples = 1;
        currentTs = ts;
        qDebug() << "New TS:" << QDateTime::fromMSecsSinceEpoch(ts);
    } else {
        temperatureTotal += temperature;
        humidityTotal += humidity;
        dewPointTotal += dewPoint;
        samples++;
    }
}
