/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef ABSTRACTDATALOGGER_H
#define ABSTRACTDATALOGGER_H

#include <QObject>

#include "sampleset.h"
#include "samplecolumns.h"

class AbstractDataLogger : public QObject
{
    Q_OBJECT
public:
    explicit AbstractDataLogger(QObject *parent = 0);

    virtual bool connectLogger();

    virtual void logData(float temperature, float humidity=0, float dewPoint=0);

    virtual void disconnectLogger() = 0;

    virtual SampleSet fetchSamples(SampleColumns columns, QDateTime start,
                                   QDateTime end) = 0;


signals:
    void error(QString title, QString message);

protected:
    virtual void insertSample(qint64 timestamp, float temperature,
                              float humidity, float dewPoint) = 0;

    qint64 nextTs();

    qint64 currentTs;
    float temperatureTotal;
    float humidityTotal;
    float dewPointTotal;
    int samples;
};

#endif // ABSTRACTDATALOGGER_H
